hipPointer_attribute

Enum hipPointer_attribute 

#[repr(u32)]
pub enum hipPointer_attribute {
Show 17 variants HIP_POINTER_ATTRIBUTE_CONTEXT = 1, HIP_POINTER_ATTRIBUTE_MEMORY_TYPE = 2, HIP_POINTER_ATTRIBUTE_DEVICE_POINTER = 3, HIP_POINTER_ATTRIBUTE_HOST_POINTER = 4, HIP_POINTER_ATTRIBUTE_P2P_TOKENS = 5, HIP_POINTER_ATTRIBUTE_SYNC_MEMOPS = 6, HIP_POINTER_ATTRIBUTE_BUFFER_ID = 7, HIP_POINTER_ATTRIBUTE_IS_MANAGED = 8, HIP_POINTER_ATTRIBUTE_DEVICE_ORDINAL = 9, HIP_POINTER_ATTRIBUTE_IS_LEGACY_HIP_IPC_CAPABLE = 10, HIP_POINTER_ATTRIBUTE_RANGE_START_ADDR = 11, HIP_POINTER_ATTRIBUTE_RANGE_SIZE = 12, HIP_POINTER_ATTRIBUTE_MAPPED = 13, HIP_POINTER_ATTRIBUTE_ALLOWED_HANDLE_TYPES = 14, HIP_POINTER_ATTRIBUTE_IS_GPU_DIRECT_RDMA_CAPABLE = 15, HIP_POINTER_ATTRIBUTE_ACCESS_FLAGS = 16, HIP_POINTER_ATTRIBUTE_MEMPOOL_HANDLE = 17,
}

Variants



HIP_POINTER_ATTRIBUTE_CONTEXT = 1

< The context on which a pointer was allocated < @warning - not supported in HIP



HIP_POINTER_ATTRIBUTE_MEMORY_TYPE = 2

< memory type describing location of a pointer



HIP_POINTER_ATTRIBUTE_DEVICE_POINTER = 3

< address at which the pointer is allocated on device



HIP_POINTER_ATTRIBUTE_HOST_POINTER = 4

< address at which the pointer is allocated on host



HIP_POINTER_ATTRIBUTE_P2P_TOKENS = 5

< A pair of tokens for use with linux kernel interface < @warning - not supported in HIP



HIP_POINTER_ATTRIBUTE_SYNC_MEMOPS = 6

< Synchronize every synchronous memory operation < initiated on this region



HIP_POINTER_ATTRIBUTE_BUFFER_ID = 7

< Unique ID for an allocated memory region



HIP_POINTER_ATTRIBUTE_IS_MANAGED = 8

< Indicates if the pointer points to managed memory



HIP_POINTER_ATTRIBUTE_DEVICE_ORDINAL = 9

< device ordinal of a device on which a pointer < was allocated or registered



HIP_POINTER_ATTRIBUTE_IS_LEGACY_HIP_IPC_CAPABLE = 10

< if this pointer maps to an allocation < that is suitable for hipIpcGetMemHandle < @warning - not supported in HIP



HIP_POINTER_ATTRIBUTE_RANGE_START_ADDR = 11

< Starting address for this requested pointer



HIP_POINTER_ATTRIBUTE_RANGE_SIZE = 12

< Size of the address range for this requested pointer



HIP_POINTER_ATTRIBUTE_MAPPED = 13

< tells if this pointer is in a valid address range < that is mapped to a backing allocation



HIP_POINTER_ATTRIBUTE_ALLOWED_HANDLE_TYPES = 14

< Bitmask of allowed hipmemAllocationHandleType < for this allocation @warning - not supported in HIP



HIP_POINTER_ATTRIBUTE_IS_GPU_DIRECT_RDMA_CAPABLE = 15

< returns if the memory referenced by < this pointer can be used with the GPUDirect RDMA API < @warning - not supported in HIP



HIP_POINTER_ATTRIBUTE_ACCESS_FLAGS = 16

< Returns the access flags the device associated with < for the corresponding memory referenced by the ptr



HIP_POINTER_ATTRIBUTE_MEMPOOL_HANDLE = 17

< Returns the mempool handle for the allocation if < it was allocated from a mempool < @warning - not supported in HIP